import 'reflect-metadata';
import bcrypt from 'bcryptjs';
import { IUsersRepository } from '@modules/users/repositories/IUsersRepostory';
import { injectable, inject } from 'tsyringe';
import { AppError } from '@shared/error/AppError';

interface IRequest{
    cpf: string,
    password: string
}

@injectable()
class LoginAuthenticationUseCase {
    constructor(
        @inject('UsersRepository')
        private usersRepository: IUsersRepository
    ) { }

    async execute({cpf, password}: IRequest) {
        const user = await this.usersRepository.findByCPF(cpf)
        if (!user) {
            throw new AppError('Not authorized', 404);
        }

        const passwordMatch = await bcrypt.compare(password, user.password)
        if(!passwordMatch) {
            throw new AppError('Not authorized', 404);
        }

       return user
        
    }
}

export {LoginAuthenticationUseCase}