import 'reflect-metadata';
import bcrypt from 'bcryptjs';
import { inject, injectable } from 'tsyringe';
import { IUsersRepository } from '@modules/users/repositories/IUsersRepostory';
import { AppError } from '@shared/error/AppError';

interface IRequest {
    name: string,
    email: string,
    password: string
    cpf: string,
    curriculo: string
}

@injectable()
class CreateUserUseCase {
    constructor(
        @inject('UsersRepository')
        private usersRepository: IUsersRepository
    ) { }

    async execute({ name, email, password, cpf, curriculo }: IRequest) {
        const userAlreadyExists = await this.usersRepository.findByEmail(email);
        if (userAlreadyExists) {
            throw new AppError('User already exists', 404);
        }
        const passwordHashed = await bcrypt.hash(password, 10);
        const user = await this.usersRepository.create({
            name,
            email,
            password: passwordHashed,
            cpf,
            curriculo,
        });

        return user;

    }
}


export { CreateUserUseCase };